PyXMake Developer Guide: PyXMake.Tools.Utility.AbstractImport Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | List of all members
PyXMake.Tools.Utility.AbstractImport Class Reference

Inherited from built-in object. More...

Inheritance diagram for PyXMake.Tools.Utility.AbstractImport:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| __new__ (cls, name, package=None, **kwargs)

## Detailed Description

Inherited from built-in object.

    Abstract (lazy) import class to construct a module with attribute which is only really loaded into memory when first accessed.
    It defaults to lazy import behavior.

    @note: Derived from https://stackoverflow.com/questions/77319516/lazy-import-from-a-module-a-k-a-lazy-evaluation-of-variable

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.Utility.AbstractImport.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Low-level initialization of parent class.

Definition at line 115 of file Utility.py.

## Member Function Documentation

## ◆ __new__()

PyXMake.Tools.Utility.AbstractImport.__new__ | ( |  | cls,
|  |  | name,
|  |  | package = None,
|  | ** | kwargs )

    An approximate implementation of import.

Definition at line 121 of file Utility.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/Utility.py